@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2024 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -31,19 +31,19 @@ void identityaddvcarddialogtest::shouldHaveDefaultValue()
 
     auto buttonGroup = dlg.findChild<QButtonGroup *>(QStringLiteral("buttongroup"));
     QVERIFY(buttonGroup);
-    QCOMPARE(dlg.duplicateMode(), IdentityAddVcardDialog::Empty);
+    QCOMPARE(dlg.duplicateMode(), IdentityAddVcardDialog::DuplicateMode::Empty);
 
-    QVERIFY(buttonGroup->button(IdentityAddVcardDialog::Empty));
-    QVERIFY(buttonGroup->button(IdentityAddVcardDialog::ExistingEntry));
-    QVERIFY(buttonGroup->button(IdentityAddVcardDialog::FromExistingVCard));
+    QVERIFY(buttonGroup->button(static_cast<int>(IdentityAddVcardDialog::DuplicateMode::Empty)));
+    QVERIFY(buttonGroup->button(static_cast<int>(IdentityAddVcardDialog::DuplicateMode::ExistingEntry)));
+    QVERIFY(buttonGroup->button(static_cast<int>(IdentityAddVcardDialog::DuplicateMode::FromExistingVCard)));
 }
 
 void identityaddvcarddialogtest::shouldEnabledUrlRequesterWhenSelectFromExistingVCard()
 {
     IdentityAddVcardDialog dlg(QStringList(), nullptr);
     auto buttonGroup = dlg.findChild<QButtonGroup *>(QStringLiteral("buttongroup"));
-    buttonGroup->button(IdentityAddVcardDialog::FromExistingVCard)->toggle();
-    QCOMPARE(dlg.duplicateMode(), IdentityAddVcardDialog::FromExistingVCard);
+    buttonGroup->button(static_cast<int>(IdentityAddVcardDialog::DuplicateMode::FromExistingVCard))->toggle();
+    QCOMPARE(dlg.duplicateMode(), IdentityAddVcardDialog::DuplicateMode::FromExistingVCard);
 
     auto identityComboBox = dlg.findChild<QComboBox *>(QStringLiteral("identity_combobox"));
     QCOMPARE(identityComboBox->isEnabled(), false);
@@ -56,8 +56,8 @@ void identityaddvcarddialogtest::shouldEnabledComboboxWhenSelectDuplicateVCard()
 {
     IdentityAddVcardDialog dlg(QStringList(), nullptr);
     auto buttonGroup = dlg.findChild<QButtonGroup *>(QStringLiteral("buttongroup"));
-    buttonGroup->button(IdentityAddVcardDialog::ExistingEntry)->toggle();
-    QCOMPARE(dlg.duplicateMode(), IdentityAddVcardDialog::ExistingEntry);
+    buttonGroup->button(static_cast<int>(IdentityAddVcardDialog::DuplicateMode::ExistingEntry))->toggle();
+    QCOMPARE(dlg.duplicateMode(), IdentityAddVcardDialog::DuplicateMode::ExistingEntry);
 
     auto identityComboBox = dlg.findChild<QComboBox *>(QStringLiteral("identity_combobox"));
     QCOMPARE(identityComboBox->isEnabled(), true);
@@ -70,15 +70,15 @@ void identityaddvcarddialogtest::shouldEnabledComboboxWhenSelectFromExistingVCar
 {
     IdentityAddVcardDialog dlg(QStringList(), nullptr);
     auto buttonGroup = dlg.findChild<QButtonGroup *>(QStringLiteral("buttongroup"));
-    buttonGroup->button(IdentityAddVcardDialog::FromExistingVCard)->toggle();
-    QCOMPARE(dlg.duplicateMode(), IdentityAddVcardDialog::FromExistingVCard);
+    buttonGroup->button(static_cast<int>(IdentityAddVcardDialog::DuplicateMode::FromExistingVCard))->toggle();
+    QCOMPARE(dlg.duplicateMode(), IdentityAddVcardDialog::DuplicateMode::FromExistingVCard);
 
     auto identityComboBox = dlg.findChild<QComboBox *>(QStringLiteral("identity_combobox"));
 
     auto urlRequester = dlg.findChild<KUrlRequester *>(QStringLiteral("kurlrequester_vcardpath"));
 
-    buttonGroup->button(IdentityAddVcardDialog::ExistingEntry)->toggle();
-    QCOMPARE(dlg.duplicateMode(), IdentityAddVcardDialog::ExistingEntry);
+    buttonGroup->button(static_cast<int>(IdentityAddVcardDialog::DuplicateMode::ExistingEntry))->toggle();
+    QCOMPARE(dlg.duplicateMode(), IdentityAddVcardDialog::DuplicateMode::ExistingEntry);
     QCOMPARE(identityComboBox->isEnabled(), true);
     QCOMPARE(urlRequester->isEnabled(), false);
 }
