@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -13,7 +13,7 @@ using namespace Qt::Literals::StringLiterals;
 #include <KIdentityManagementCore/IdentityManager>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <MessageComposer/Composer>
+#include <MessageComposer/ComposerJob>
 #include <MessageComposer/MessageHelper>
 #include <MessageCore/StringUtil>
 #include <QFile>
@@ -80,7 +80,7 @@ void OpenComposerJob::start()
             f.close();
         }
         if (!str.isEmpty()) {
-            mContext = KMail::Composer::NoTemplate;
+            mContext = KMail::Composer::TemplateContext::NoTemplate;
             mMsg->setBody(str);
             slotOpenComposer();
         } else {
@@ -90,7 +90,7 @@ void OpenComposerJob::start()
             parser->process(mMsg);
         }
     } else if (!mOpenComposerSettings.mBody.isEmpty()) {
-        mContext = KMail::Composer::NoTemplate;
+        mContext = KMail::Composer::TemplateContext::NoTemplate;
         mMsg->setBody(mOpenComposerSettings.mBody.toUtf8());
         mMsg->assemble();
         mMsg->parse();
